==> chaostoolkit-k6-0.3.3.tar.gz: chaostoolkit-k6-0.3.3/setup.py <==
#!/usr/bin/env python
"""chaostoolkit-k6 extension builder and installer"""

import sys
import io

import setuptools

name = "chaostoolkit-k6"
desc = "Chaos Toolkit Extension for k6."

with io.open("README.md", encoding="utf-8") as strm:
    long_desc = strm.read()

classifiers = [
    "Development Status :: 2 - Pre-Alpha",
    "Intended Audience :: Developers",
    "License :: Freely Distributable",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: Apache Software License",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: Implementation",
    "Programming Language :: Python :: Implementation :: CPython",
]
author = "k6"
author_email = "avocados@k6.io"
url = "http://chaostoolkit.org"
license = "Apache License Version 2.0"
packages = ["chaosk6"]

needs_pytest = set(["pytest", "test"]).intersection(sys.argv)
pytest_runner = ["pytest_runner"] if needs_pytest else []

test_require = []
with io.open('requirements-dev.txt') as f:
    test_require = [l.strip() for l in f if not l.startswith('#')]

install_require = []
with io.open("requirements.txt") as f:
    install_require = [l.strip() for l in f if not l.startswith("#")]

setup_params = dict(
    name=name,
    version="0.3.3",
    description=desc,
    long_description=long_desc,
    classifiers=classifiers,
    author=author,
    author_email=author_email,
    url=url,
    license=license,
    packages=packages,
    include_package_data=True,
    install_requires=install_require,
    tests_require=test_require,
    setup_requires=pytest_runner,
    python_requires=">=3.5.*",
)


def main():
    """Package installation entry point."""
    setuptools.setup(**setup_params)


if __name__ == "__main__":
    main()

==> chaostoolkit-k6-0.3.4.tar.gz: chaostoolkit-k6-0.3.4/setup.py <==
#!/usr/bin/env python
"""chaostoolkit-k6 extension builder and installer"""

import sys
import io

import setuptools

name = "chaostoolkit-k6"
desc = "Chaos Toolkit Extension for k6."

with io.open("README.md", encoding="utf-8") as strm:
    long_desc = strm.read()

classifiers = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "License :: Freely Distributable",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: Apache Software License",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: Implementation",
    "Programming Language :: Python :: Implementation :: CPython",
]
author = "k6"
author_email = "avocados@k6.io"
url = "http://chaostoolkit.org"
license = "Apache License Version 2.0"
packages = ["chaosk6"]

needs_pytest = set(["pytest", "test"]).intersection(sys.argv)
pytest_runner = ["pytest_runner"] if needs_pytest else []

test_require = []
with io.open('requirements-dev.txt') as f:
    test_require = [l.strip() for l in f if not l.startswith('#')]

install_require = []
with io.open("requirements.txt") as f:
    install_require = [l.strip() for l in f if not l.startswith("#")]

setup_params = dict(
    name=name,
    version="0.3.4",
    description=desc,
    long_description=long_desc,
    classifiers=classifiers,
    author=author,
    author_email=author_email,
    url=url,
    license=license,
    packages=packages,
    include_package_data=True,
    install_requires=install_require,
    tests_require=test_require,
    setup_requires=pytest_runner,
    python_requires=">=3.7",
)


def main():
    """Package installation entry point."""
    setuptools.setup(**setup_params)


if __name__ == "__main__":
    main()
